function [C Ceq] = C3MR_constraints(x)
%Constraints - calculate the constraint values of the C3MR model for
%optimization

h=ActXServer('UnisimDesign.Application');
hyCase = h.Activedocument;
sol=hyCase.Solver;
f = hyCase.Flowsheet;

sol.CanSolve = 0 ;

P1_C3 = x(1) ; % Lowest pressure in propane cycle
P2_C3 = x(2) ; % Second lowest pressure in propane cycle
P3_C3 = x(3) ; % Third lowest pressure in propane cycle
P3_MR = x(4) ; % Pressure out of K105, highest pressure in MR cycle
Pc_MR = x(5) ; % Pressure in cold end of plant, after J-T expansion of MR
flow1_C3 = x(6) ; % Propane flow to NG precooling
flow2_C3 = x(7) ; % Propane flow to MR precooling
flow_MR = x(8) ;  % Flow of mixed refrigerant
P1_MR = x(9) ; % Pressure out of K1-MR
P2_MR = x(10) ; % PRessure out of K-100


f.MaterialStreams.Item('C3-11-NG').PressureValue = P1_C3;
f.MaterialStreams.Item('C3-7-NG').PressureValue = P2_C3;
f.MaterialStreams.Item('C3-3-NG').PressureValue = P3_C3;
f.MaterialStreams.Item('4').PressureValue = P3_MR;
f.MaterialStreams.Item('MR-8-V').PressureValue = Pc_MR; 
f.MaterialStreams.Item('C3-2-NG').MolarFlowValue = flow1_C3; 
f.MaterialStreams.Item('C3-2-MR').MolarFlowValue = flow2_C3; 
f.MaterialStreams.Item('MR-14').MolarFlowValue = flow_MR; 
f.MaterialStreams.Item('MR-15').PressureValue = P1_MR;
f.MaterialStreams.Item('2').PressureValue = P2_MR;

sol.CanSolve = 1 ;

T_minapp = 0.5;

Ceq = [] ; %No equality constraints
C=zeros(12,1);
C(1) =  T_minapp - f.Operations.Item('E-100').MinimumApproachValue ;
C(2) =  T_minapp - f.Operations.Item('E-101').MinimumApproachValue ;
C(3) =  T_minapp - f.Operations.Item('E-102').MinimumApproachValue ;
C(4) =  T_minapp - f.Operations.Item('E-103').MinimumApproachValue ;
C(5) =  T_minapp - f.Operations.Item('E-104').MinimumApproachValue ;
C(6) =  T_minapp - f.Operations.Item('E-105').MinimumApproachValue ;
C(7) =  T_minapp - f.Operations.Item('LNG-1').MinApproachValue ;
C(8) =  T_minapp - f.Operations.Item('LNG-2').MinApproachValue ;
C(9) = 10 - f.Operations.Item('SPRDSHT-2').Imports.Item('A2: C7:').CellValue ;
C(10) = 10 - f.Operations.Item('SPRDSHT-2').Imports.Item('A3: C8:').CellValue ;
C(11) = 10 - f.Operations.Item('SPRDSHT-2').Imports.Item('A4: C9:').CellValue ;
C(12) = f.MaterialStreams.Item('NG-6').TemperatureValue + 156.9;

%x

%C

%Cval = zeros(12,1);
%Cval(1) =  f.Operations.Item('E-100').MinimumApproachValue ;
%Cval(2) =  f.Operations.Item('E-101').MinimumApproachValue ;
%Cval(3) =  f.Operations.Item('E-102').MinimumApproachValue ;
%Cval(4) =  f.Operations.Item('E-103').MinimumApproachValue ;
%Cval(5) =  f.Operations.Item('E-104').MinimumApproachValue ;
%Cval(6) =  f.Operations.Item('E-105').MinimumApproachValue ;
%Cval(7) =  f.Operations.Item('LNG-1').MinApproachValue ;
%Cval(8) =  f.Operations.Item('LNG-2').MinApproachValue ;
%Cval(9) =  f.Operations.Item('SPRDSHT-2').Imports.Item('A2: C7:').CellValue ;
%Cval(10) = f.Operations.Item('SPRDSHT-2').Imports.Item('A3: C8:').CellValue ;
%Cval(11) = f.Operations.Item('SPRDSHT-2').Imports.Item('A4: C9:').CellValue ;
%Cval(12) = f.MaterialStreams.Item('NG-6').TemperatureValue;

end

