%Optimizer for C3MR process

% The "import/export" units between Unisim and Matlab are as follows:
% Pressure: kPa
% Temperature: degrees C
% Molar flow: kmol/s

%Access UniSim flowsheet
h=ActXServer('UnisimDesign.Application');
hyCase = h.Activedocument;
sol=hyCase.Solver;
f = hyCase.Flowsheet;

%Get initial values from UniSim base case
x0 = zeros(10,1);
x0(1) = f.MaterialStreams.Item('C3-11-NG').PressureValue; %P1_C3
x0(2) = f.MaterialStreams.Item('C3-7-NG').PressureValue; %P2_C3
x0(3) = f.MaterialStreams.Item('C3-3-NG').PressureValue; %P3_C3
x0(4) = f.MaterialStreams.Item('4').PressureValue; %P3_MR
x0(5) = f.MaterialStreams.Item('MR-8-V').PressureValue; %Pc_MR 
x0(6) = f.MaterialStreams.Item('C3-2-NG').MolarFlowValue; %flow1_C3 
x0(7) = f.MaterialStreams.Item('C3-2-MR').MolarFlowValue; %flow2_C3 
x0(8) = f.MaterialStreams.Item('MR-14').MolarFlowValue; %flow_MR 
x0(9) = f.MaterialStreams.Item('MR-15').PressureValue; %P1_MR
x0(10) = f.MaterialStreams.Item('2').PressureValue; %P2_MR


%Set lower and upper bounds so UniSim is certain to converge
lb = [
    125
    240
    470
    4800
    540
    13400/3600
    68300/3600
    116000/3600
    2200
    3000
    ];

ub = [
    130
    260
    490
    5000
    560
    14000/3600
    69000/3600
    118000/3600
    2400
    3700
    ];
    
%Call optimizer function fmincon to minimize function objaektiv with given
%bounds and constraints in C3MR_constraints.
options = optimset('TolFun',1e-6,'DiffMinChange',1e-3,'MaxFunEval',1000,'Display','iter','TypicalX', x0, 'PlotFcns', @optimplotfirstorderopt);
[x,fval,exitflag,output,lambda,grad,hessian] = fmincon(@objaektiv,x0,[],[],[],[],lb,ub,@C3MR_constraints,options)

sol.CanSolve = 0 ;
